//
//  BTViewController.m
//  coreBluetoothiPhone
//
//  Created by Luigi D'Acunto on 09/04/14.
//  Copyright (c) 2014 Luigi D'Acunto. All rights reserved.
//

#import "BTViewController.h"
#import <CoreBluetooth/CoreBluetooth.h>

@interface BTViewController ()<CBCentralManagerDelegate,CBPeripheralDelegate,UITextFieldDelegate>{
    CBCentralManager *myCentralManger;
    CBPeripheral *myPeripheralBC127;
    CBCharacteristic *myCharacteristic;
}

@end

@implementation BTViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    myCentralManger = [[CBCentralManager alloc]initWithDelegate:self queue:nil options:0];
    self.sendTextField.delegate =self;
    self.receiveTextField.delegate=self;
    self.sendTextField.placeholder=@"Text To Send";
    self.receiveTextField.placeholder=@"Received Text";
    self.connectButton.titleLabel.textAlignment  = NSTextAlignmentRight;
    self.connectButton.titleLabel.text = @"SCAN";
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}
-(void)centralManager:(CBCentralManager *)central didDiscoverPeripheral:(CBPeripheral *)peripheral advertisementData:(NSDictionary *)advertisementData RSSI:(NSNumber *)RSSI{
    NSLog(@"Trovata Periferica");
    NSLog(@"Nome: %@",peripheral.name);
    NSLog(@"UUID: %@",[peripheral.identifier UUIDString]);
    NSLog(@"Description: %@",[peripheral description]);
    NSLog(@"Advertisement: %@",[advertisementData description]);
    NSLog(@"RSSI: %@",[RSSI description]);
    self.connectButton.enabled=YES;
    
    self.connectButton.titleLabel.text = @"CONNECT";
    self.notificationLabel.text=@"Found Peripheral";
    self.deviceNameLabel.text = peripheral.name;
    myPeripheralBC127 = peripheral;
}
- (void)centralManagerDidUpdateState:(CBCentralManager *)central{
    
    NSString *status;
    if(central.state==0)
    status= @"Unknown Device";
     else if(central.state==1)
    status=@"Resetting Device";
     else if(central.state==2)
    status=@"Unsupported Device";
     else if(central.state==3)
    status=@"Unauthorized Device";
     else if(central.state==4)
    status=@"Bluetooth Off";
     else if(central.state==5)
     {
         status=@"Device Ready";
         
     }
    NSLog(@"%@",status);
    self.notificationLabel.text=status;
}
- (void)centralManager:(CBCentralManager *)central didConnectPeripheral:(CBPeripheral *)peripheral{
    peripheral.delegate=self;
    self.connectButton.enabled=YES;
     self.connectButton.titleLabel.text = @"DISCONNECT";
    NSString *status;
    if(peripheral.state==0)
        status=@"Disconnected";
    else if(peripheral.state==1)
        status=@"Connecting";
    else if(peripheral.state==2)
        status=@"Connected";

    NSLog(@"%@",status);

    self.notificationLabel.text=status;
    [myCentralManger stopScan];
    [peripheral discoverServices:nil];
}
-(void)peripheral:(CBPeripheral *)peripheral didDiscoverServices:(NSError *)error{
    
    for(CBService *service in peripheral.services){
        NSLog(@"Service: %@",service);
        [peripheral discoverCharacteristics:nil forService:service];
    }
}
-(void)peripheral:(CBPeripheral *)peripheral didDiscoverCharacteristicsForService:(CBService *)service error:(NSError *)error{
    
    for(CBCharacteristic *caratteristica in service.characteristics){
        NSLog(@"charachteristic.desc--->%@",caratteristica.description);

        myCharacteristic = caratteristica;
        [peripheral setNotifyValue:YES forCharacteristic:caratteristica];
        
    }
    
}
- (void)peripheral:(CBPeripheral *)peripheral didWriteValueForCharacteristic:(CBCharacteristic *)characteristic error:(NSError *)error{
    
    NSString* newStr = [[NSString alloc] initWithData:characteristic.value encoding:NSUTF8StringEncoding];
    NSLog(@"I wrote the value: %@", newStr );
    
}
/*
-(void) peripheral:(CBPeripheral *)peripheral didUpdateNotificationStateForCharacteristic:(CBCharacteristic *)characteristic error:(NSError *)error{
    
}*/
-(void)peripheral:(CBPeripheral *)peripheral didUpdateValueForCharacteristic:(CBCharacteristic *)characteristic error:(NSError *)error{
   // NSLog(@"I received the value: %@",characteristic.value);
    self.notificationLabel.text=@"Message Received";
 
    NSString* newStr = [[NSString alloc] initWithData:characteristic.value encoding:NSUTF8StringEncoding];
    self.receiveTextField.text = newStr;
    NSLog(@"I received the value: %@",newStr);
}
- (IBAction)buttonPressed:(id)sender {
    
    //SEND BUTTON PRESSED
        [self textFieldShouldReturn:sender];

         NSData* data = [self.sendTextField.text dataUsingEncoding:NSUTF8StringEncoding];
         [myPeripheralBC127 writeValue:data forCharacteristic:myCharacteristic type:CBCharacteristicWriteWithResponse];
        self.lastMessageLabel.text=self.sendTextField.text;
        self.sendTextField.text=@"";
        [self textFieldShouldReturn:self.sendTextField];
        self.notificationLabel.text=@"Message Sent";
    
}
- (BOOL)textFieldShouldReturn:(UITextField *)textField{
    [textField resignFirstResponder];
    
    return YES;
}
- (IBAction)connectDevice:(id)sender {
    
    NSString *status;
    if([self.connectButton.titleLabel.text isEqualToString:@"SCAN"]){
        NSLog(@"Trying To Scan");
        self.notificationLabel.text=@"Scanning";
        self.deviceNameLabel.text=@"Scanning";
        [myCentralManger scanForPeripheralsWithServices:nil options:0];
        self.connectButton.titleLabel.text = @"..AT WORK..";
        self.connectButton.enabled=NO;
    }
    else if([self.connectButton.titleLabel.text isEqualToString:@"CONNECT"])
    {
        NSLog(@"Trying To Connect");
        if(myPeripheralBC127.state==0)
        {
            status=@"Disconnected";
            [myCentralManger connectPeripheral:myPeripheralBC127 options:nil];
            self.connectButton.enabled=NO;
            self.connectButton.titleLabel.text = @"..AT WORK..";
            self.notificationLabel.text=status;
        }
         if(myPeripheralBC127.state==1)
        {
            status=@"Connecting";
            self.notificationLabel.text=status;
        }
         if(myPeripheralBC127.state==2)
        {
            status=@"Connected";
            self.notificationLabel.text=status;
            self.connectButton.titleLabel.text = @"DISCONNECT";
        }
        
    }
    else if([self.connectButton.titleLabel.text isEqualToString:@"DISCONNECT"])
    {
            NSLog(@"Trying To Disconnect");
            [myCentralManger cancelPeripheralConnection:myPeripheralBC127];
    }

}
- (void)centralManager:(CBCentralManager *)central didDisconnectPeripheral:(CBPeripheral *)peripheral error:(NSError *)error{
    
    NSString *status;
    self.connectButton.titleLabel.text = @"SCAN";
    status=@"Disconnected";
    self.notificationLabel.text=status;
    self.deviceNameLabel.text = @"No Device To Connect";

}
@end
